# Aggregation Output Table Schema

This is the common schema for a range of output tables. It is captured on this separate page due to its length.

This schema applies to the following tables:
- author
- country
- funder
- group
- institution
- journal
- publisher
- region
- subregion

``` eval_rst
.. csv-table::
   :file: ../schemas/aggregate_latest.csv
   :width: 100%
   :header-rows: 1
```